@@ -70,11 +70,17 @@ JOB_EVENT_STATUS_TRANSITIONS = {
 
 
 RESET_REASONS = [
-    'SIGTERM',
+    '_condor_stdout: (errno 2) No such file',
+    'sigterm',
     'killed',
-    'Transfer input files failure',
-    'Transfer output files failure',
+    'transfer input files failure',
+    'transfer output files failure',
+    'cpu consumption limit exceeded',
+    'operation timed out',
 ]
+#    'memory limit exceeded',
+#    'local storage limit on worker node exceeded',
+#    'execution time limit exceeded',
 
 
 def parse_usage(usage: str) -> int:
@@ -207,14 +213,18 @@ class CondorSubmit:
         for infile in infiles:
             if infile.url.startswith('gsiftp:') and not x509_proxy:
                 raise RuntimeError('need x509 proxy for gridftp!')
-            if infile.transfer == Transfer.MAYBE:
-                url = 'iceprod://maybe-' + infile.url
-            else:
+            if infile.url[0] == '/':
                 url = infile.url
+            else:
+                if infile.transfer == Transfer.MAYBE:
+                    url = 'iceprod-plugin://maybe-' + infile.url
+                else:
+                    url = 'iceprod-plugin://true-' + infile.url
+                basename = Path(infile.url).name
+                if basename != infile.local:
+                    url += '?mapping='+infile.local
+                    # mapping.append((basename,infile.local))
             files.append(url)
-            basename = Path(infile.url).name
-            if basename != infile.local:
-                mapping.append((basename,infile.local))
         ads = {}
         if mapping:
             ads['PreCmd'] = f'"{self.precmd.name}"'
@@ -231,7 +241,7 @@ class CondorSubmit:
         for outfile in outfiles:
             files.append(outfile.local)
             if outfile.transfer == Transfer.MAYBE:
-                url = 'iceprod://maybe-' + outfile.url
+                url = 'iceprod-plugin://maybe-' + outfile.url
             else:
                 url = outfile.url
             mapping.append((outfile.local, url))
@@ -320,7 +330,7 @@ transfer_output_remaps = $(outremaps)
         for task in tasks:
             submit_dir = self.create_submit_dir(task, jel_dir)
             s = WriteToScript(task=task, workdir=submit_dir)
-            executable = await s.convert()
+            executable = await s.convert(transfer=True)
             logger.debug('running task with exe %r', executable)
 
             ads = self.AD_DEFAULTS.copy()
@@ -473,7 +483,9 @@ class Grid(grid.BaseGrid):
             counts[job.status] += 1
 
         idle_jobs = counts[JobStatus.IDLE]
+        logger.info('idle jobs: %r', idle_jobs)
         processing_jobs = counts[JobStatus.RUNNING]
+        logger.info('processing jobs: %r', processing_jobs)
         queue_tot_max = self.cfg['queue']['max_total_tasks_on_queue'] - idle_jobs - processing_jobs
         queue_idle_max = self.cfg['queue']['max_idle_tasks_on_queue'] - idle_jobs
         queue_interval_max = self.cfg['queue']['max_tasks_per_submit']
@@ -641,8 +653,16 @@ class Grid(grid.BaseGrid):
                 future = None
                 if reason:
                     stats['error_summary'] = reason
+                    # check condor error for reset reason
                     for text in RESET_REASONS:
-                        if text in reason:
+                        if text.lower() in reason.lower():
+                            future = self.task_reset(job, reason=reason)
+                            break
+                if future is None and stderr and stderr.is_file():
+                    # check stderr for reset reason
+                    reason = stderr.open().read()
+                    for text in RESET_REASONS:
+                        if text.lower() in reason.lower():
                             future = self.task_reset(job, reason=reason)
                             break
                 if future is None:
