@@ -31,6 +31,8 @@ from wipac_dev_tools import from_environment
 
 import iceprod
 from iceprod.roles_groups import GROUPS
+from iceprod.core.config import CONFIG_SCHEMA as DATASET_SCHEMA
+from iceprod.server.config import CONFIG_SCHEMA as SERVER_SCHEMA
 import iceprod.core.functions
 from iceprod.server import documentation
 from iceprod.server.module import FakeStatsClient, StatsClientIgnoreErrors
@@ -260,6 +262,18 @@ class Default(PublicHandler):
         self.render('main.html')
 
 
+class Schemas(PublicHandler):
+    """Handle /schemas/v3/(.*) urls"""
+    @catch_error
+    async def get(self, schema):
+        if schema == 'dataset.schema.json':
+            self.write(DATASET_SCHEMA)
+        elif schema == 'config.schema.json':
+            self.write(SERVER_SCHEMA)
+        else:
+            raise tornado.web.HTTPError(404, reason='unknown schema')
+
+
 class Submit(PublicHandler):
     """Handle /submit urls"""
     @authenticated
@@ -386,18 +400,22 @@ class Dataset(PublicHandler):
         tasks = await self.rest_client.request('GET','/datasets/{}/task_counts/status'.format(dataset_id))
         task_info = await self.rest_client.request('GET','/datasets/{}/task_counts/name_status'.format(dataset_id))
         task_stats = await self.rest_client.request('GET','/datasets/{}/task_stats'.format(dataset_id))
-        config = await self.rest_client.request('GET','/config/{}'.format(dataset_id))
+        try:
+            config = await self.rest_client.request('GET','/config/{}'.format(dataset_id))
+        except Exception:
+            config = {}
         for t in task_info:
             logger.info('task_info[%s] = %r', t, task_info[t])
             type_ = 'UNK'
-            for task in config['tasks']:
+            for task in config.get('tasks', []):
                 if 'name' in task and task['name'] == t:
                     type_ = 'GPU' if 'requirements' in task and 'gpu' in task['requirements'] and task['requirements']['gpu'] else 'CPU'
                     break
             task_info[t] = {
                 'name': t,
                 'type': type_,
-                'waiting': task_info[t].get('waiting', 0) + task_info[t].get('idle', 0),
+                'idle': task_info[t].get('idle', 0),
+                'waiting': task_info[t].get('waiting', 0),
                 'queued': task_info[t].get('queued', 0),
                 'running': task_info[t].get('processing', 0),
                 'complete': task_info[t].get('complete', 0),
@@ -789,6 +807,7 @@ class Server:
         server.add_route(r"/", Default, handler_args)
         server.add_route(r"/submit", Submit, handler_args)
         server.add_route(r"/config", Config, handler_args)
+        server.add_route(r"/schemas/v3/([\w\.]+)", Schemas, handler_args)
         server.add_route(r"/dataset", DatasetBrowse, handler_args)
         server.add_route(r"/dataset/(\w+)", Dataset, handler_args)
         server.add_route(r"/dataset/(\w+)/task", TaskBrowse, handler_args)
